@@ -4,7 +4,6 @@ in HTML reports.
 """
 from __future__ import unicode_literals
 from os.path import basename
-from IPython.utils import openpy
 import pygments
 from pygments.lexers import TextLexer, _iter_lexerclasses
 from pygments.formatters import HtmlFormatter
@@ -12,6 +11,25 @@ from pygments.util import ClassNotFound
 import six
 import fnmatch
 
+# If tokenize.open (Python>=3.2) is available, use that to open python files.
+# Otherwise, use detect_encoding from lib2to3 (2.6, 2.7) wrapped the same way
+# that tokenize.open would have.
+try:
+    from tokenize import open as openpy
+except ImportError:
+    def openpy(filename):
+        from lib2to3.pgen2.tokenize import detect_encoding
+        import io
+
+        # The following is copied from tokenize.py in Python 3.2,
+        # Copyright (c) 2001-2014 Python Software Foundation; All Rights Reserved
+        buffer = io.open(filename, 'rb')
+        encoding, lines = detect_encoding(buffer.readline)
+        buffer.seek(0)
+        text = io.TextIOWrapper(buffer, encoding, line_buffering=True)
+        text.mode = 'r'
+        return text
+
 def guess_lexer_for_filename(_fn, _text, **options):
     """
     Ripped from the tip of pygments
@@ -172,7 +190,7 @@ class Snippet(object):
         Raises an `IOError` if the file could not be loaded.
         """
         # Load the contents of the file
-        with openpy.open(src_path) as src_file:
+        with openpy(src_path) as src_file:
             contents = src_file.read()
 
         # Convert the source file to unicode (Python < 3)
